@@ -65,7 +65,8 @@ static struct msgb *make_msgb(const char *m)
 #define LOGCLI(cli, fmt, args...) do { \
 		struct timeval tv; \
 		osmo_gettimeofday(&tv, NULL); \
-		printf("{%lu.%06lu} [%s] Client's %s(): " fmt, tv.tv_sec, tv.tv_usec, \
+		printf("{%lu.%06lu} [%s] Client's %s(): " fmt, \
+		       (unsigned int long) tv.tv_sec, (unsigned int long) tv.tv_usec, \
 		       osmo_stream_cli_get_data(cli) ? "OK" : "NA", __func__, ##args); \
 	} while (0)
 
@@ -243,7 +244,8 @@ static struct osmo_stream_cli *make_client(void *ctx, const char *host, unsigned
 #define LOGSRV(srv, fmt, args...) do { \
 		struct timeval tv; \
 		osmo_gettimeofday(&tv, NULL); \
-		printf("{%lu.%06lu} [%s|%s] Server's %s(): " fmt,  tv.tv_sec, tv.tv_usec, \
+		printf("{%lu.%06lu} [%s|%s] Server's %s(): " fmt, \
+		       (unsigned int long) tv.tv_sec, (unsigned int long) tv.tv_usec, \
 		       osmo_stream_srv_get_data(srv) ? "OK" : "NA", \
 		       osmo_stream_srv_link_get_data(osmo_stream_srv_get_master(srv)) ? "OK" : "NA", \
 		       __func__, ##args); \
@@ -364,21 +366,24 @@ static void test_recon(void *ctx, const char *host, unsigned port, unsigned step
 		osmo_select_main(0);
 		osmo_gettimeofday(&tv, NULL);
 		fprintf(stderr, "\n{%lu.%06lu} %s test step %u [client %s, server %s], FD reg %u\n",
-			tv.tv_sec, tv.tv_usec, ASTR(autoreconnect), steps,
+			(unsigned int long) tv.tv_sec, (unsigned int long) tv.tv_usec,
+			ASTR(autoreconnect), steps,
 			osmo_stream_cli_get_data(cli) ? "OK" : "NA",
 			osmo_stream_srv_link_get_data(lnk) ? "OK" : "NA",
 			osmo_fd_is_registered(osmo_stream_cli_get_ofd(cli)));
 
 		if (test_stop_requested(lnk)) {
 			printf("{%lu.%06lu} Server requested test termination\n",
-			       tv.tv_sec, tv.tv_usec);
+			       (unsigned int long) tv.tv_sec, (unsigned int long) tv.tv_usec);
 			steps = 0;
 		}
 	}
 
 	osmo_stream_cli_destroy(cli);
 	osmo_stream_srv_link_close(lnk);
-	printf("{%lu.%06lu} %s test complete.\n\n", tv.tv_sec, tv.tv_usec, ASTR(autoreconnect));
+	printf("{%lu.%06lu} %s test complete.\n\n",
+	       (unsigned int long) tv.tv_sec, (unsigned int long) tv.tv_usec,
+	       ASTR(autoreconnect));
 }
 
 /* Segmentation test code (using IPA) */
@@ -516,7 +521,7 @@ static int test_segm_ipa_stream_srv_cli_read_cb(struct osmo_stream_cli *osc, int
 	}
 
 	LOGCLI(osc, "Received message from stream (payload len = %" PRIu16 ")\n", msgb_length(msg));
-	if (ipac_msg_type < 0 || 5 < ipac_msg_type) {
+	if (5 < ipac_msg_type) {
 		fprintf(stderr, "Received unexpected IPAC message type %"PRIu8"\n", ipac_msg_type);
 		msgb_free(msg);
 		return -ENOMSG;
@@ -740,7 +745,7 @@ int test_segm_ipa_stream_cli_srv_read_cb(struct osmo_stream_srv *conn, int res,
 		fprintf(stderr, "Cannot allocate message\n");
 		return -ENOMEM;
 	}
-	LOGSRV(conn, "Received message from stream (total len including stripped headers = %lu)\n",
+	LOGSRV(conn, "Received message from stream (total len including stripped headers = %zu)\n",
 	       osmo_ntohs(h->len) + sizeof(*h));
 	if (5 < ipa_msg_type) {
 		fprintf(stderr, "Received unexpected IPAC message type %"PRIu8"\n", ipa_msg_type);
